==> chromium-88.0.4307.0.tar.xz: chromium-88.0.4307.0/chromeos/network/network_state_handler_observer.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chromeos/network/network_state_handler_observer.h"

namespace chromeos {

NetworkStateHandlerObserver::NetworkStateHandlerObserver() = default;

NetworkStateHandlerObserver::~NetworkStateHandlerObserver() = default;

void NetworkStateHandlerObserver::NetworkListChanged() {}

void NetworkStateHandlerObserver::DeviceListChanged() {}

void NetworkStateHandlerObserver::DefaultNetworkChanged(
    const NetworkState* network) {}

void NetworkStateHandlerObserver::PortalStateChanged(
    const NetworkState* default_network,
    NetworkState::PortalState portal_state) {}

void NetworkStateHandlerObserver::NetworkConnectionStateChanged(
    const NetworkState* network) {}

void NetworkStateHandlerObserver::ActiveNetworksChanged(
    const std::vector<const NetworkState*>& active_networks) {}

void NetworkStateHandlerObserver::NetworkPropertiesUpdated(
    const NetworkState* network) {}

void NetworkStateHandlerObserver::DevicePropertiesUpdated(
    const chromeos::DeviceState* device) {}

void NetworkStateHandlerObserver::ScanRequested(
    const NetworkTypePattern& type) {}

void NetworkStateHandlerObserver::ScanCompleted(const DeviceState* device) {}

void NetworkStateHandlerObserver::HostnameChanged(const std::string& hostname) {
}

void NetworkStateHandlerObserver::OnShuttingDown() {}

}  // namespace chromeos

==> chromium-91.0.4472.38.tar.xz: chromium-91.0.4472.38/chromeos/network/network_state_handler_observer.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chromeos/network/network_state_handler_observer.h"

namespace chromeos {

NetworkStateHandlerObserver::NetworkStateHandlerObserver() = default;

NetworkStateHandlerObserver::~NetworkStateHandlerObserver() = default;

void NetworkStateHandlerObserver::NetworkListChanged() {}

void NetworkStateHandlerObserver::DeviceListChanged() {}

void NetworkStateHandlerObserver::DefaultNetworkChanged(
    const NetworkState* network) {}

void NetworkStateHandlerObserver::PortalStateChanged(
    const NetworkState* default_network,
    NetworkState::PortalState portal_state) {}

void NetworkStateHandlerObserver::NetworkConnectionStateChanged(
    const NetworkState* network) {}

void NetworkStateHandlerObserver::ActiveNetworksChanged(
    const std::vector<const NetworkState*>& active_networks) {}

void NetworkStateHandlerObserver::NetworkPropertiesUpdated(
    const NetworkState* network) {}

void NetworkStateHandlerObserver::DevicePropertiesUpdated(
    const chromeos::DeviceState* device) {}

void NetworkStateHandlerObserver::ScanRequested(
    const NetworkTypePattern& type) {}

void NetworkStateHandlerObserver::ScanStarted(const DeviceState* device) {}

void NetworkStateHandlerObserver::ScanCompleted(const DeviceState* device) {}

void NetworkStateHandlerObserver::NetworkIdentifierTransitioned(
    const std::string& old_service_path,
    const std::string& new_service_path,
    const std::string& old_guid,
    const std::string& new_guid) {}

void NetworkStateHandlerObserver::HostnameChanged(const std::string& hostname) {
}

void NetworkStateHandlerObserver::OnShuttingDown() {}

}  // namespace chromeos
